<?php

function sprite_settings_form() {
  $form = array();

  $file_types = array();
  $file_types['jpg'] = 'jpg';
  $file_types['png'] = 'png';
  $file_types['gif'] = 'gif';

  $form['sprite_extension'] = array(
    '#type' => 'select',
    '#title' => t('Sprite File Type'),
    '#default_value' => variable_get('sprite_extension', 'jpg'),
    '#options' => $file_types,
    '#description' => t('Please select the file type for the sprites that are generated'),
  );
  
  $form['sprite_class'] = array(
    '#type' => 'textfield',
    '#title' => t('CSS Class Name'),
    '#description' => t("The CSS class name that will be added to each of the sprites' div tags"),
    '#size' => 60,
    '#maxlength' => 30,
    '#default_value' => variable_get('sprite_class', 'sprite'),
    '#element_validate' => array('sprite_text_field_validate'),
  );

  $form['sprite_id_prefix'] = array(
    '#type' => 'textfield',
    '#title' => t('CSS ID Prefix'),
    '#description' => t("The CSS ID prefix that appears on each sprite's div.  The ID is based on [prefix]-[registry]-[count]."),
    '#size' => 60,
    '#maxlength' => 30,
    '#default_value' => variable_get('sprite_id_prefix', 'sprite'),
    '#element_validate' => array('sprite_text_field_validate'),
  );

  $form['sprite_filepath'] = array(
    '#type' => 'textfield',
    '#title' => t('Sprite Filepath'),
    '#description' => t("The name of the directory inside the site's files directory that will contain the files generated by the module."),
    '#size' => 60,
    '#maxlength' => 30,
    '#default_value' => variable_get('sprite_filepath', 'sprite'),
    '#element_validate' => array('sprite_text_field_validate'),
  );

  return system_settings_form($form);
}

function sprite_manage_form() {
  $header = array(t('Registry'), t('Action'));
  $rows = array();

  $sprite_dirs = file_scan_directory(file_directory_path().'/'.variable_get('sprite_filepath', 'sprite'), ".*", array('.', '..', 'CVS'), 0, false);
  ksort($sprite_dirs);

  foreach ($sprite_dirs as $sprite_registry) {
    $row = array();
    $row[] = $sprite_registry->basename;
    $row[] = l(t('Flush'), 'admin/settings/sprite/'. $sprite_registry->basename .'/flush');
    $rows[] = $row;
  }

  $output = theme('table', $header, $rows);

  return $output;
}

function sprite_registry_flush_form(&$form_state, $registry) {
  if (empty($registry)) {
    drupal_set_message(t('The requested registry was not found'), 'error');
    $form_state['redirect'] = 'admin/settings/sprite/manage';
  }

  $form = array();
  $form['registry'] = array('#type' => 'value', '#value' => $registry);
  return confirm_form(
    $form,
    t('Are you sure you want to flush the sprites created under the %registry registry?',
      array('%registry' => $registry)
    ),
    'admin/settings/sprite/manage',
    t('This action cannot be undone.'),
    t('Flush'),  t('Cancel')
  );
}

function sprite_registry_flush_form_submit($form, &$form_state) {
  $registry = sprite_registry_flush($form_state['values']['registry']);
  drupal_set_message(t('The sprite %registry registry was flushed.', array('%registry' => $registry)));
  $form_state['redirect'] = 'admin/settings/sprite/manage';
}

function sprite_registry_title_callback($title, $registry = array()) {
  $replacements = array();
  if (!empty($registry)) {
    $replacements['!registry'] = $registry;
  }
  return t($title, $replacements);
}

function sprite_text_field_validate($element) {
  if (strlen($element['#value']) <= 0) {
    form_set_error($element['#name'], t('The %title must contain atleast one character.', array('%title' => $element['#title'])));
  } else if (preg_match("/^[a-zA-Z]+[a-zA-Z0-9-_]*$/", $element['#value']) == false) {
    form_set_error($element['#name'], t('The %title must start with a letter and may only contain letters, numbers, underscores, and hyphens.', array('%title' => $element['#title'])));
  }
}